@@ -3,8 +3,8 @@
 ;; Copyright (C) 2021 Isa Mert Gurbuz
 
 ;; Author: Isa Mert Gurbuz <isamert@protonmail.com>
-;; Package-Version: 1.1.0
-;; Package-Revision: 4f24d187e2bf
+;; Package-Version: 20251011.1449
+;; Package-Revision: aa5c58856cfb
 ;; URL: https://github.com/isamert/orgmdb.el
 ;; Package-Requires: ((emacs "27.1") (dash "2.11.0") (s "1.12.0") (org "8.0.0"))
 
@@ -180,16 +180,6 @@ under the header."
   :type 'string
   :group 'orgmdb)
 
-(defcustom orgmdb-not-available-property-value "N/A"
-  "String used as a placeholder when a property value is unavailable.
-
-When non-nil, OrgMDB inserts this string for any property whose value
-cannot be determined while filling properties (i.e. not returned from
-OMDB).  When nil, OrgMDB skips creating such properties entirely instead
-of inserting a placeholder."
-  :type 'string
-  :group 'orgmdb)
-
 ;;;###autoload
 (defvar orgmdb-omdb-url
   "https://www.omdbapi.com"
@@ -530,18 +520,15 @@ for check how parameter detection works."
   (orgmdb--ensure-response-is-successful info)
   (--each
       (remq 'poster orgmdb-fill-property-list)
-    (let* ((key (if orgmdb-upcase-properties
-                    (upcase (format "%s" it))
-                  (format "%s" it)))
-           (val (-as->
-                 (format "orgmdb-%s" it) fn
-                 (intern fn)
-                 (apply fn `(,info ,orgmdb-not-available-property-value))))
-           (unavailable? (equal val orgmdb-not-available-property-value)))
-      (when (or (not unavailable?)
-                (and orgmdb-not-available-property-value
-                     (not (org-entry-get nil key nil))))
-        (org-entry-put nil key val))))
+    (-as->
+     (format "orgmdb-%s" it) fn
+     (intern fn)
+     (apply fn `(,info "N/A"))
+     (org-entry-put nil
+                    (if orgmdb-upcase-properties
+                        (upcase (format "%s" it))
+                      (format "%s" it))
+                    fn)))
   (when (memq 'poster orgmdb-fill-property-list)
     (let ((path (orgmdb--download-image-for info)))
       (save-excursion
@@ -652,7 +639,6 @@ SHOULD-SET-TITLE does."
                              (outline-up-heading 1 t))))
                 (throw 'break nil))))))))
 
-;;;###autoload
 (defun orgmdb-act ()
   "Act on the current movie/series/episode object.
 It'll display several actions (like filling proprties etc.)
@@ -678,19 +664,16 @@ related to the current object."
      (t
       (user-error "Not on an org header or an episode object")))))
 
-;;;###autoload
 (defun orgmdb-act-on-movie ()
   "List possible actions on the movie at point."
   (interactive)
   (orgmdb--act-on 'movie))
 
-;;;###autoload
 (defun orgmdb-act-on-show ()
   "List possible actions on the show at point."
   (interactive)
   (orgmdb--act-on 'show))
 
-;;;###autoload
 (defun orgmdb-act-on-episode (&optional episode)
   "List possible actions on the EPISODE at point."
   (interactive)
